@@ -38,17 +38,14 @@ and any other block braces.
 C<PPI::Structure::Block> has no methods beyond those provided by the
 standard L<PPI::Structure>, L<PPI::Node> and L<PPI::Element> methods.
 
-Got any ideas for methods? Submit a report to rt.cpan.org!
-
 =cut
 
 use strict;
-use base 'PPI::Structure';
+use PPI::Structure ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.203';
-}
+our $VERSION = '1.278';
+
+our @ISA = "PPI::Structure";
 
 
 
@@ -58,7 +55,7 @@ BEGIN {
 # PPI::Element Methods
 
 # This is a scope boundary
-sub scope { 1 }
+sub scope() { 1 }
 
 1;
 
@@ -74,7 +71,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2008 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
